// Copyright (c) 1995, 1996 Regents of the University of California.
// All rights reserved.
//
// This software was developed by the Arcadia project
// at the University of California, Irvine.
//
// Redistribution and use in source and binary forms are permitted
// provided that the above copyright notice and this paragraph are
// duplicated in all such forms and that any documentation,
// advertising materials, and other materials related to such
// distribution and use acknowledge that the software was developed
// by the University of California, Irvine.  The name of the
// University may not be used to endorse or promote products derived
// from this software without specific prior written permission.
// THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
// IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
// WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.

// File: BasicApplication.java
// Class: BasicApplication
// original author: jrobbins@ics.uci.edu
// $Id: BasicApplication.java,v 1.7 1997/01/24 19:22:51 jrobbins Exp $

//package uci.graphedit.mydemo;

import webflow.frontend.*;
import java.awt.*;
import java.util.*;
import java.lang.*;
import uci.graphedit.*;
import webflow.frontend.WFtree.*;

class myEditorFrame extends EditorFrame 
{
   myEditorFrame(NetList n)
   { super(n);
     System.out.println(" myEditorFrame is created ");
   }

   public boolean handleEvent(Event e)
   { 
      //System.out.println(" in handleEvent() of myEditorFrame ");
      if(e.id == Event.WINDOW_DESTROY)
      {   System.out.println("Event.WINDOW_DESTROY is received ");
          editor().executeAction(new ActionQuit(),e);
          return true;
      }
      return super.handleEvent(e); 
   }

}

class gef1Frame extends Frame
               implements UserInterfaceDebug
{
   /**
   * Editor to whom we are going to send the
   * Event.WINDOW_DESTROY event.
   */
   private Editor myEditor = null;

   /**
   * You have to provide the Editor object.
   */
   gef1Frame(Editor _myEditor)
   { myEditor = _myEditor; }

 /**
   * This only handles the Event.WINDOW_DESTROY event
   * end tells its editor object to execute ActionQuit.
   */
   public boolean
   handleEvent(Event e)
   {
     boolean ret = false;

     switch(e.id)
     {
       case Event.WINDOW_ICONIFY : break;

       case Event.WINDOW_DESTROY :
            if(myEditor != null)
            {
              if(DEBUG==true)
                System.out.println(" Event.WINDOW_DESTROY is being received !");

              /** Make sure Editor is WebEditor Object */
              if( myEditor instanceof WebEditor )
                  myEditor.executeAction(new ActionWebFlowQuit((WebEditor)myEditor),e);
              else
                  myEditor.executeAction(new ActionQuit(),e);

              ret = true;
            }// end of if
            break;

     } // end of switch()

     return ret || super.handleEvent(e);

   }// end of handleEvent()

}// end of class gefFrame



/** 
* A simple example of the minimum code needed to build an
* application using GEF. 
*/
public class 
BasicApplication 
{

  ////////////////////////////////////////////////////////////////
  // Instance Variables
  
  //private EditorFrame _edFrame;
  private myEditorFrame _edFrame;

  private gef1Frame _palFrame;
  private PaletteTop _pal;

  private ControlPanel control;
  private gef1Frame     _cntFrame;

  private PaletteTop   _MolPalette;
  //private PaletteModuleTree   _ModTreePalette;
  private PaletteTop   _ModTreePalette;
  private gef1Frame     _MolFrame;

  ////////////////////////////////////////////////////////////////
  // Constructors
  
  public BasicApplication() {
    //_edFrame = new EditorFrame(new NetList());
    _edFrame = new myEditorFrame(new NetList());
    _edFrame.setTitle("BasicApplication Editor");
    _edFrame.move(10, 10);
    _edFrame.show();

    _palFrame = new gef1Frame(_edFrame.editor());
    _pal = new PaletteTop(new PaletteFig());

    _pal.frame(_palFrame);
    _pal.definePanel();
    _palFrame.setLayout(new BorderLayout());
    _palFrame.add("Center", _pal);
    _palFrame.pack();
    _palFrame.setTitle("Palette");
    _palFrame.move(500, 10);
    _palFrame.show();

    
    ModuleTree mt = new ModuleTree("timucin",
                        //"http://www.cis.syr.edu/~htozdemi/modules.txt");
                        "http://osprey1.npac.syr.edu:9080/webflow/webflow/modules.txt");
    
    if(mt.load()==true)
    {
      System.out.println("Modules are loaded");

      Vector pals = new Vector();

      //_ModTreePalette = new PaletteModuleTree(mt);

      
      _ModTreePalette = new PaletteTop( new PaletteScrollTreeView(
                            new ModuleTreeNode((ModuleTreeItem)mt.getItems().firstElement()),350,200));

      //pals.addElement( _ModTreePalette );
      pals.addElement( new PaletteFig());
      pals.addElement( new PaletteExample() );
      Palette Right = new PaletteTop(new PaletteCompound(pals,1,2,"GEF "));
      
      Vector pal1 = new Vector();
      pal1.addElement( _ModTreePalette );
      pal1.addElement(new PaletteSticky(new PaletteCompound(pals,2,1,"GEF ")) ); 

    //_MolPalette = new PaletteTop(new PaletteModuleTree(mt));
    //_MolPalette = new PaletteModuleTree(mt);

    _MolPalette = new PaletteTop(new PaletteCompound(pal1,1,2,"Module"));
    
    _MolFrame = new gef1Frame(_edFrame.editor());

    _MolPalette.frame(_MolFrame);
    _ModTreePalette.frame(_MolFrame);

    _MolPalette.definePanel();
    _MolFrame.setLayout(new BorderLayout());
    _MolFrame.add("Center", _MolPalette);
    _MolFrame.pack();
    _MolFrame.setTitle("Modules");
    _MolFrame.move(500,95);
    _MolFrame.show();
    }

    _cntFrame = new gef1Frame(_edFrame.editor());
    control = new ControlPanel(_edFrame.editor());

    _cntFrame.setTitle("Control");
    _cntFrame.setLayout( new BorderLayout() );
    _cntFrame.add("Center", control);
    _cntFrame.pack();
    _cntFrame.move(500,10);
    _cntFrame.show();

  }

  ////////////////////////////////////////////////////////////////
  // Main
  
  public static void main(String args[]) {
    BasicApplication demo = new BasicApplication();
  }

} /* end class BasicApplication */

